####################
Supported Countries
####################
The following is a list of supported countries, and their country codes for
the Indeed API.

=====================  =============
Country                Country code
=====================  =============
Antarctica             ``aq``
Argentina              ``ar``
Australia              ``au``
Austria                ``at``
Bahrain                ``bh``
Belgium                ``be``
Brazil                 ``br``
Canada                 ``ca``
Chile                  ``cl``
China                  ``cn``
Colombia               ``co``
Costa Rica             ``cr``
Czech Republic         ``cz``
Denmark                ``dk``
Ecuador                ``ec``
Egypt                  ``eg``
Finland                ``fi``
France                 ``fr``
Germany                ``de``
Greece                 ``gr``
Hong Kong              ``hk``
Hungary                ``hu``
India                  ``in``
Indonesia              ``id``
Ireland                ``ie``
Israel                 ``il``
Italy                  ``it``
Japan                  ``jp``
Kuwait                 ``kw``
Luxembourg             ``lu``
Malaysia               ``my``
Mexico                 ``mx``
Morocco                ``ma``
Netherlands            ``nl``
New Zealand            ``nz``
Nigeria                ``ng``
Norway                 ``no``
Oman                   ``om``
Pakistan               ``pk``
Panama                 ``pa``
Peru                   ``pe``
Philippines            ``ph``
Poland                 ``pl``
Portugal               ``pt``
Qatar                  ``qa``
Romania                ``ro``
Russia                 ``ru``
Saudi Arabia           ``sa``
Singapore              ``sg``
South Africa           ``za``
South Korea            ``kr``
Spain                  ``es``
Sweden                 ``se``
Switzerland            ``ch``
Taiwan                 ``tw``
Thailand               ``th``
Turkey                 ``tr``
Ukraine                ``ua``
United Arab Emirates   ``ae``
United Kingdom         ``gb``
United States          ``us``
Uruguay                ``uy``
Venezuela              ``ve``
Vietnam                ``vn``
=====================  =============
